using System.Threading.Channels;
using FitConnect;
using FitConnect.Encryption;
using FitConnect.Models;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.Logging;

namespace DemoRunner;

public static class SenderDemo {
    public static void Run(IConfigurationRoot config, ILogger logger) {
        var clientId = config["FitConnect:Sender:ClientId"];
        var clientSecret = config["FitConnect:Sender:ClientSecret"];
        var destinationId = config["FitConnect:Sender:DestinationId"];
        var leikaKey = config["FitConnect:Sender:LeikaKey"];


        OutputHelper.PrintSender();
        var submission = Client
            .GetSender(FitConnectEnvironment.Testing, clientId, clientSecret, logger)
            .WithDestination(destinationId)
            .WithServiceType("FIT Connect Demo", leikaKey)
            .WithAttachments(new Attachment("Test.pdf", "Test Attachment"))
            .WithJsonData("{\"message\":\"Hello World\"}")
            .Submit();
    }

    public static void RunEncrypted(IConfigurationRoot config, ILogger logger) {
        var clientId = config["FitConnect:Sender:ClientId"];
        var clientSecret = config["FitConnect:Sender:ClientSecret"];
        var destinationId = config["FitConnect:Sender:DestinationId"];
        var leikaKey = config["FitConnect:Sender:LeikaKey"];


        FitEncryption encryption;
        Dictionary<string, string>? encryptedAttachments = null;
        string? encryptedMetadata = null;
        string? encryptedData = null;

        var sender = Client
            .GetSender(FitConnectEnvironment.Testing, clientId, clientSecret, logger)
            .WithDestination(destinationId,
                (k) => {
                    logger?.LogInformation("Received public key: {Key}", k);
                    encryption = new FitEncryption(k, logger);
                    encryptedAttachments = new Dictionary<string, string>() { { "", "" } };
                    encryptedMetadata = "";
                    encryptedData = encryption.Encrypt("{\"message\":\"Hello World\"}");
                });

        // Return the public key to the JavaScript client
        // Come back later with the encrypted data
        
        sender.WithServiceType("FIT Connect Demo", leikaKey)
            .WithEncryptedAttachments(encryptedAttachments)
            .WithEncryptedMetaData(encryptedMetadata)
            .WithEncryptedData(encryptedData)
            .Submit();
    }
}
