using FitConnect.Interfaces.Sender;
using FitConnect.Models;
using FitConnect.Services.Models.v1.Submission;
using Microsoft.Extensions.Logging;

namespace FitConnect;

public partial class Sender {
    public IWithEncryptedAttachments WithEncryptedAttachments(
        Dictionary<string, string> attachments) {
        if (Submission?.ServiceType == null) {
            Logger?.LogError("Submission has no service type");
            throw new ArgumentException("Submission has no service type");
        }

        var createSubmissionDto = (CreateSubmissionDto)Submission;
        createSubmissionDto.AnnouncedAttachments = attachments.Keys.ToList();
        var created = SubmissionService.CreateSubmission(createSubmissionDto);
        Submission.Id = created.SubmissionId;
        Submission.CaseId = created.CaseId;

        if (Submission?.Id == null)
            throw new ArgumentException("Submission is not ready");

        Logger?.LogInformation("Uploading pre encrypted attachments");
        UploadAttachmentsAsync(Submission.Id!, attachments);
        return this;
    }

    public ISenderWithEncryptedData WithEncryptedData(string data) {
        if (Submission?.Id == null)
            throw new ArgumentException("Submission is not ready");

        Submission.EncryptedData = data;
        return this;
    }

    public ISenderWithEncryptedMetaData WithEncryptedMetaData(string metaData) {
        if (Submission?.Id == null)
            throw new ArgumentException("Submission is not ready");

        Submission.EncryptedMetadata = metaData;
        return this;
    }


    Submission ISenderWithEncryptedData.Submit() {
        if (Submission == null) {
            Logger?.LogCritical("Submission is null on submit");
            throw new InvalidOperationException("Submission is not ready");
        }

        Logger?.LogTrace("Encrypted metadata: {EncryptedMeta}", Submission.EncryptedMetadata);
        var result = SubmissionService
            .SubmitSubmission(Submission.Id!, (SubmitSubmissionDto)Submission).Result;

        Logger?.LogInformation("Submission sent");
        return Submission;
    }
}
