using FitConnect.Models;

namespace FitConnect.Interfaces.Sender;

public interface ISenderWithService {
    /// <summary>
    ///     Sends the submission with a list of attachments
    /// </summary>
    /// <param name="attachments">that are sent with the submission</param>
    /// <returns>the step where additional data can be added to the submission</returns>
    public ISenderWithAttachments WithAttachments(IEnumerable<Attachment> attachments);

    /// <summary>
    ///     Sends the submission with a list of attachments
    /// </summary>
    /// <param name="attachments">that are sent with the submission</param>
    /// <returns>the step where additional data can be added to the submission</returns>
    public ISenderWithAttachments WithAttachments(params Attachment[] attachments);

    /// <summary>
    /// Adding the encrypted attachments to the submission
    /// </summary>
    /// <param name="attachments">Dictionary with the UUID and the encrypted attachment</param>
    /// <returns></returns>
    public IWithEncryptedAttachments WithEncryptedAttachments(
        Dictionary<string, string> attachments);
}

public interface IWithEncryptedAttachments {
    public ISenderWithEncryptedMetaData WithEncryptedMetaData(string metaData);
}

public interface ISenderWithEncryptedMetaData : ISenderWithEncryptedData {
    public ISenderWithEncryptedData WithEncryptedData(string data);
}

public interface ISenderWithEncryptedData {
    public Submission Submit();
}
